; Programa: Funciones para testear agentes de juego al sokoban
;
; Asignatura: Introduccin a la Inteligencia Artificial
;             ETSII - ULL
; Prctica: 5a (sistemas de produccin)
; Profesor: Patricio Garca (patricio@etsii.ull.es)
; Fecha:    7/6/2005
; Comentarios:
;
;           Cdigos necesarios para testear los agentes inteligente
;           para jugar a el sokoban. Se basa en la funcin TEST, 
;           ver el correspondiente help.
;
;           Para poder utilizarlo directamente es necesario cambiar 
;           los valores de las variables siguientes:
;             VARIABLE-GENERADOS: Nombre de la variable de nodos generados
;             VARIABLE-EXPANDIDOS: Nombre de la variable de nodos expandidos
;
;           Combiene tambin colocar a NULL la funcin de impresin 
;           de estados y no olvidar compilar todos los cdigos 
;           (ver (HELP 'COMPILE-FILE)) para acelerar las ejecuciones.
;
; Ejemplo de llamada a pruebas (ejecutar manualmente)
; ---------------------------------------------------
; (test problemas)
;
;
; Ejemplo de llamada a pruebas que deja rastro en /scratch/sokoban/hof.txt
; -----------------------------------------------------------------------
; (test problemas :hof t)
;

; Versin de este test
(defvar *version-test* 0.2 "Version de test.lsp")

; Se cargan las librerias
(load "sokoban") 
(load "shell") 
(load "q_search")
(load "a_star")

; Poner a continuacin cdigo necesario para cargar tus agentes
; -------------------------------------------------------------
; Ojo, no olvidar compilar todo antes (compile-file "<fich-agente.lsp>")
; ----------------------------------------------------------------------
(load "agentes-intl") 

; Se coloca o define la funcin de impresin a null (revisa tu cdigo)
; --------------------------------------------------------------------
(setf func-vis-estado #'null)

; Nombre de las variables globales de tu cdigo que guarda
; el nmero de nodos generados en la ltima ejecucin
; --------------------------------------------------------
(defvar variable-generados 'generados)

; Nombre de las variables globales de tu cdigo que guarda
; el nmero de nodos expandidos en la ltima ejecucin
; --------------------------------------------------------
(defvar variable-expandidos 'expandidos)


; Lista de problemas a testear en formato de sublistas con:
; (<nombre_agente> <tipo_problema> <numero_repeticiones>)
; ---------------------------------------------------------
(defvar problemas '(
		    (3 BP 100)
		    (3 BA 100)
		    (3 BA* 100)
		    (NIL BP 100)
		    (NIL BA 100)
		    (NIL BA* 100)
		    ("/scratch/sokoban/kids03.scr" BP 10)
		    ("/scratch/sokoban/kids03.scr" BA 10)
		    ("/scratch/sokoban/kids03.scr" BA* 100)
		    ("/scratch/sokoban/kids16.scr" BP 1)
		    ("/scratch/sokoban/kids16.scr" BA 1)
		    ("/scratch/sokoban/kids16.scr" BA* 10)
		    ("/scratch/sokoban/kids18.scr" BP 1)
		    ("/scratch/sokoban/kids18.scr" BA 1)
		    ("/scratch/sokoban/kids18.scr" BA* 10)
		    ("/scratch/sokoban/kids01.scr" BP 1)
		    ("/scratch/sokoban/kids01.scr" BA 1)
		    ("/scratch/sokoban/kids01.scr" BA* 10)))


; Funcin que lanza las pruebas
; -----------------------------

(defun test (problemas &key hof)
  " - Funcin: TEST (PROBLEMAS &KEY HOF)

Inicia la ejecucin de una batera de problemas sobre una lista de agentes e imprime por la salida estandar los resultados de dichas ejecuciones. FICHS es la lista de prametros :fich a probar (ver INIC-BLOQ). AGENTES es la lista de las funciones que implementan los agentes a probar. REPETICIONES es el nmero de veces que se ejecuta cada problema, parmetro :num de INIC-BLOQ. HOF equivale al parmetro :hof, para dejar rastro en el fichero /scratch/bloques/hof.txt.
Devuelve T si todo va bien, imprimiendo por la salida estandar los resultadosde las ejecuciones. Si se desean recoger a un fichero se puede utilizar el comando DRIBBLE (ver (HELP 'DRIBBLE))."
  (let (res)
    (dolist (problema problemas t)
      (setf res
	    (inic-soko (second problema)
		       :tipo (first problema)
		       :num (third problema)
		       :hof hof))
      (format t "Tipo: ~S  Agente: ~S  Num: ~D  Push/par: ~D  Mov/par: ~D  Tim/par: ~,2F   Generados/par: ~D  Expandidos/par: ~D~%"
		(first problema)
		(second problema)
		(first res)
		(/ (second (second res)) (first res))
		(/ (first (second res)) (first res))
		(float (/ (third res) (first res)))
		(eval variable-generados) 
		(eval variable-expandidos)))))


; Ejemplo de llamada a pruebas (ejecutar manualmente)
; ---------------------------------------------------
#|
(test problemas)
|#

; Ejemplo de llamada a pruebas que deja rastro en /scratch/bloques/hof.txt
; ------------------------------------------------------------------------
#|
(test problemas :hof t)
|#

